@@ -1,37 +1,31 @@
 
-context("Update")
-
 test_that("update() finds packages requiring updates from CRAN", {
 
   skip_on_cran()
 
   renv_tests_scope()
-  renv::init()
+  init()
 
-  renv::install("breakfast@0.1.0")
+  install("breakfast@0.1.0")
   expect_true(renv_package_version("breakfast") == "0.1.0")
 
-  local({
-    renv_scope_sink()
-    renv::update()
-  })
-
+  update()
   expect_true(renv_package_version("breakfast") == "1.0.0")
 
 })
 
 test_that("update() can upgrade GitHub packages", {
 
-  skip_on_cran()
   skip_if(getRversion() < "3.5.3")
-  skip_if(is.na(Sys.getenv("GITHUB_PAT", unset = NA)))
-  skip_sometimes()
+  skip_on_cran()
+  skip_if_no_github_auth()
+  skip_slow()
 
   renv_tests_scope()
-  renv::init()
+  init()
 
   # download old commit from GitHub and track master
-  renv::install("kevinushey/skeleton@5fd5d3bc616794f869e47fdf3a8b4bcaa2afcf53")
+  install("kevinushey/skeleton@5fd5d3bc616794f869e47fdf3a8b4bcaa2afcf53")
 
   pkgpath <- find.package("skeleton")
   descpath <- file.path(pkgpath, "DESCRIPTION")
@@ -54,23 +48,27 @@ test_that("update() can upgrade GitHub packages", {
 
 test_that("update() can upgrade Git packages", {
 
-  skip_on_cran()
   skip_if(getRversion() < "3.5.3")
-  skip_sometimes()
+  skip_on_cran()
+  skip_if_no_github_auth()
+  skip_slow()
 
-  # # this test appears to fail on CI (ssh clone from GitHub disallowed?)
+  # this test appears to fail on CI (ssh clone from GitHub disallowed?)
   testthat::skip_on_ci()
 
   renv_tests_scope()
-  renv::init()
+  init()
 
   # download old commit from GitHub and track master
-  remotes::install_git(
-    url          = "https://github.com/kevinushey/skeleton",
-    ref          = "5fd5d3bc616794f869e47fdf3a8b4bcaa2afcf53",
-    quiet        = TRUE,
-    INSTALL_opts = "--no-multiarch"
-  )
+  local({
+    renv_scope_envvars(RENV_AUTOLOADER_ENABLED = FALSE)
+    remotes::install_git(
+      url          = "https://github.com/kevinushey/skeleton",
+      ref          = "5fd5d3bc616794f869e47fdf3a8b4bcaa2afcf53",
+      quiet        = TRUE,
+      INSTALL_opts = "--no-multiarch"
+    )
+  })
 
   pkgpath <- find.package("skeleton")
   descpath <- file.path(pkgpath, "DESCRIPTION")
@@ -90,3 +88,55 @@ test_that("update() can upgrade Git packages", {
   expect_true(dcf$Version == "1.0.1")
 
 })
+
+test_that("can upgrade bitbucket", {
+
+  skip_on_cran()
+
+  latest <- outdated <- renv_remotes_resolve("bitbucket::kevinushey/skeleton")
+  outdated$Version <- "1.0.0"
+  outdated$RemoteSha <- "5fd5d3b"
+
+  updated <- renv_update_find(list(outdated))
+
+  expect_equal(updated$skeleton$Version, latest$Version)
+  expect_equal(updated$skeleton$RemoteSha, latest$RemoteSha)
+
+})
+
+test_that("can upgrade gitlab", {
+
+  skip_on_cran()
+
+  latest <- outdated <- renv_remotes_resolve("gitlab::kevinushey/skeleton")
+  outdated$Version <- "1.0.0"
+  outdated$RemoteSha <- "5fd5d3b"
+
+  updated <- renv_update_find(list(outdated))
+
+  expect_equal(updated$skeleton$Version, latest$Version)
+  expect_equal(updated$skeleton$RemoteSha, latest$RemoteSha)
+
+})
+
+test_that("we guard against invalid mc.cores values", {
+
+  skip_on_windows()
+  renv_scope_options(renv.config.updates.parallel = TRUE)
+
+  local({
+    renv_scope_options(mc.cores = 4L)
+    expect_equal(renv_parallel_cores(), 4L)
+  })
+
+  local({
+    renv_scope_options(mc.cores = NA)
+    expect_equal(renv_parallel_cores(), 1L)
+  })
+
+  local({
+    renv_scope_options(mc.cores = "oops")
+    expect_equal(renv_parallel_cores(), 1L)
+  })
+
+})
